## GLUE3D: General Language Understanding Evaluation for 3D Point Clouds

Official PyPI package for [**GLUE3D: General Language Understanding Evaluation for 3D Point Clouds**](https://github.com/giorgio-mariani/GLUE3D).

GLUE3D is a Q&A benchmark for evaluation of 3D-LLMs object understanding capabilities. It is built around 128 richly textured surfaces spanning creatures, objects, architecture and transport. Each surface is provided as a 50 k-point RGB point cloud, a 8K-point RGB point cloud, a 512 × 512 RGB rendering, and five RGB-D multiviews.

The package can be easily installed with the command:

```bash
pip install glue3d
```

A more in-detail description of the GLUE3D Q&A evaluation tasks, together with usage examples, are available on the project [repository](https://github.com/giorgio-mariani/GLUE3D).
